==> bee_hotel-2.21.0-rc1.tar.gz: bee_hotel/modules/beehotel_vertical/src/Form/TimeRangeForm.php <==
<?php

namespace Drupal\beehotel_vertical\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * A form to define a time range for Vertical.
 */
class TimeRangeForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'beehotel_vertical_timerange';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return "";
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $session = $this->getRequest()->getSession();
    $range = $session->get('beehotel_requested_range');

    $items = $this->timeranges();
    foreach ($items as $key => $item) {
      $ranges[$key] = render($item['label']);
    }

    $form['range'] = [
      '#title' => $this->t('Time range'),
      '#description' => $this->t("Which time range do want to see?"),
      '#type' => 'select',
      '#options' => $ranges,
      '#default_value' => $range,
    ];

    $form['actions']['#type'] = 'actions';

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Search'),
      '#button_type' => 'primary',
    ];
    $form['#theme'] = 'vertical_form';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // We will need these values inside preprocess.
    $session = $this->getRequest()->getSession();
    $session->set('beehotel_requested_range', $form_state->getValue('range'));
  }

  /**
   * List of timerange for vertical.
   *
   *  @todo add coming months.
   */
  public function timeRanges() {

    $ranges = [
      'cw' => [
        'label' => $this->t("Current week"),
        'value' => "",
        'rows' => "7",
      ],

      'cm' => [
        'label' => $this->t("Current month"),
        'value' => "",
        'rows' => date("t"),
      ],

      'n15d' => [
        'label' => $this->t("Next 15 days"),
        'value' => "",
        'rows' => 15,
      ],

      'n30d' => [
        'label' => $this->t("Next 30 days"),
        'rows' => 30,
      ],

      'n45d' => [
        'label' => $this->t("Next 45 days"),
        'rows' => 45,
      ],

      'n60d' => [
        'label' => $this->t("Next 60 days"),
        'rows' => 60,
      ],
      'n180d' => [
        'label' => $this->t("Next 180 days"),
        'rows' => 180,
      ],
    ];
    return $ranges;
  }

}

==> bee_hotel-2.21.7.tar.gz: bee_hotel/modules/beehotel_vertical/src/Form/TimeRangeForm.php <==
<?php

namespace Drupal\beehotel_vertical\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\beehotel_vertical\BeehotelVertical;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A form to define a time range for Vertical.
 */
class TimeRangeForm extends FormBase {

  /**
   * The BeeHotel vertical time range.
   *
   * @var \Drupal\beehotel_vertical\BeehotelVertical
   */
  private $beehotelVertical;

  /**
   * Constructs a new Vertical object.
   *
   * @param \Drupal\beehotel_vertical\BeehotelVertical $beehotel_vertical
   *   The BeeHotel Vertical Class for features.
   */
  public function __construct(BeehotelVertical $beehotel_vertical) {
    $this->beehotelVertical = $beehotel_vertical;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('beehotel_vertical.beehotelvertical'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'beehotel_vertical_timerange';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return "";
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $session = $this->getRequest()->getSession();
    $range = $session->get('beehotel_requested_range');

    $items = $this->beehotelVertical->timeRanges();
    foreach ($items as $key => $item) {
      $ranges[$key] = $item['label'];
    }

    $form['range'] = [
      '#title' => $this->t('Time range'),
      '#description' => $this->t("Which time range do want to see?"),
      '#type' => 'select',
      '#options' => $ranges,
      '#default_value' => $range,
    ];

    $form['actions']['#type'] = 'actions';

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Search'),
      '#button_type' => 'primary',
    ];
    $form['#theme'] = 'vertical_form';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // We will need these values inside preprocess.
    $session = $this->getRequest()->getSession();
    $session->set('beehotel_requested_range', $form_state->getValue('range'));
  }

}
